---

slug: /deploy-overview
---

# Deployment overview

seekdb provides two deployment modes. You can choose the appropriate deployment mode based on your business scenario.

* **Embedded mode**: seekdb runs as a "library" inside your application. It can easily run on various "endpoints", making it suitable for mobile application development, desktop application development, and application development on IoT and edge devices. In this mode, you can connect and manage seekdb through Python scripts or SDKs.

* **Server mode**: Uses single-machine deployment, suitable for CI/CD and testing. It is simple, has low operational costs, and the server starts quickly. In this mode, you can connect and manage seekdb through MySQL client or SDKs.

## Deployment methods

Different deployment modes provide various deployment methods that you can choose based on your needs.

* **Embedded mode**:

   * Deploy seekdb using the pyseekdb SDK provided by seekdb.
 
      For detailed deployment operations, see [Embedded deployment mode](600.python-seekdb.md).

* **Server mode**:
  
  * Deploy seekdb using yum install.
    
      For detailed deployment operations, see [Deploy seekdb using yum install](700.server-mode/100.deploy-by-systemd.md).
  
  * Deploy seekdb in a container environment.
    
      For detailed deployment operations, see [Deploy seekdb in a container environment](700.server-mode/200.deploy-by-docker.md).
  
  * Deploy OceanBase Desktop.
    
      OceanBase Desktop is a desktop application for managing and operating seekdb. It provides a graphical interface that enables users to easily perform database management, query execution, data import and export, and other operations.

      For detailed deployment operations, see [Deploy OceanBase Desktop](700.server-mode/300.deploy-oceanbase-desktop.md).
